import { EventEmitter, OnInit, QueryList } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { HammerGestureConfig } from '@angular/platform-browser';
import { ICalendarDate, WEEKDAYS } from './calendar';
import { IgxCalendarDateDirective } from './calendar.directives';
export declare enum CalendarView {
    DEFAULT = 0,
    YEAR = 1,
    DECADE = 2,
}
export declare enum CalendarSelection {
    SINGLE = "single",
    MULTI = "multi",
    RANGE = "range",
}
export declare class CalendarHammerConfig extends HammerGestureConfig {
    overrides: {
        pan: {
            direction: number;
            threshold: number;
        };
    };
}
/**
 * **Ignite UI for Angular Calendar** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/calendar.html)
 *
 * The Ignite UI Calendar provides an easy way to display a calendar and allow users to select dates using single, multiple
 * or range selection.
 *
 * Example:
 * ```html
 * <igx-calendar selection="range"></igx-calendar>
 * ```
 */
export declare class IgxCalendarComponent implements OnInit, ControlValueAccessor {
    id: string;
    /**
     * An `@Input` property indicating the start of the week.
     * Defaults to Sunday.
     */
    weekStart: WEEKDAYS | number;
    /**
     * An `@Input` property indicating the locale of the calendar.
     * Expects a valid BCP 47 language tag.
     */
    locale: string;
    /**
     * An @Input property controlling the selection mechanism of the calendar.
     * Allowed values are `single`, `multi` and `range`. Defaults to `single`.
     * Providing and invalid value will throw an error.
     *
     * Changing the type of selection in the calendar resets the currently
     * selected values if any.
     */
    selection: string;
    /**
     * An @Input property controlling the the year/month that will be presented in the default view when the calendar renders.
     * By default it is the current year/month.
     */
    viewDate: Date;
    /**
     * Gets and sets the selected date(s) of the calendar.
     *
     * When the calendar selection is set to `single`, it accepts/returns
     * a single `Date` object.
     * Otherwise it is an array of `Date` objects.
     */
    value: Date | Date[];
    /**
     * An @Input property which controls the formatting of the date components to use in
     * formatted output.
     */
    formatOptions: object;
    /**
     * An @Input property controlling whether the 'day', 'month' and 'year' should be rendered
     * according to the locale and formatOptions, if any.
     * Affects rendering in the default view, month view and year view.
     * Does not affect rendering in the header.
     */
    formatViews: object;
    /**
     * An @Input property controlling the layout of the calendar.
     * When `vertical` is set to `true` the calendar header will be displayed on the side of
     * the calendar body, otherwise it will be above (default).
     */
    vertical: boolean;
    onSelection: EventEmitter<Date | Date[]>;
    /**
     * @hidden
     */
    dates: QueryList<IgxCalendarDateDirective>;
    /**
     * The default `tabindex` attribute for the component.
     *
     * @hidden
     */
    tabindex: number;
    /**
     * The default aria role attribute for the component.
     *
     * @hidden
     */
    role: string;
    /**
     * The default aria lebelled by attribute for the component.
     *
     * @hidden
     */
    ariaLabelledBy: string;
    /**
     * The default css class applied to the component.
     *
     * @hidden
     */
    readonly styleClass: string;
    /**
     * Returns an array of date objects which are then used to
     * properly render the month names.
     *
     * Used in the template of the component
     *
     * @hidden
     */
    readonly months: Date[];
    /**
     * Returns an array of date objects which are then used to properly
     * render the years.
     *
     * Used in the template of the component.
     *
     * @hidden
     */
    readonly decade: number[];
    readonly isDefaultView: boolean;
    readonly isYearView: boolean;
    readonly isDecadeView: boolean;
    /**
     * Returns the current active view of the calendar.
     */
    readonly activeView: CalendarView;
    /**
     * @hidden
     */
    readonly monthAction: string;
    headerTemplate: any;
    subheaderTemplate: any;
    /**
     * Returns the context for the template marked with the `igxCalendarHeader` directive.
     *
     */
    readonly headerContext: {
        $implicit: {
            date: Date;
            full: string;
            monthView: () => void;
            yearView: () => void;
        };
    };
    /**
     * Returns the context for the template marked with either `igxCalendarSubHeaderMonth`
     * or `igxCalendarSubHeaderYear` directive.
     */
    readonly context: {
        $implicit: {
            date: Date;
            full: string;
            monthView: () => void;
            yearView: () => void;
        };
    };
    /**
     * @hidden
     */
    readonly headerDate: Date;
    /**
     * @hidden
     */
    private headerTemplateDirective;
    /**
     * @hidden
     */
    private subheaderTemplateDirective;
    private _viewDate;
    private calendarModel;
    private _activeView;
    private selectedDates;
    private _selection;
    private _rangeStarted;
    private _monthAction;
    private _formatOptions;
    private _formatViews;
    /**
     * @hidden
     */
    constructor();
    /**
     * @hidden
     */
    ngOnInit(): void;
    /**
     * @hidden
     */
    registerOnChange(fn: (v: Date) => void): void;
    /**
     * @hidden
     */
    registerOnTouched(fn: () => void): void;
    /**
     * @hidden
     */
    writeValue(value: Date | Date[]): void;
    /**
     * Returns the locale representation of the month in the month view if enabled,
     * otherwise returns the default `Date.getMonth()` value.
     *
     * @hidden
     */
    formattedMonth(value: Date): string;
    /**
     * Returns the locale representation of the date in the default view if enabled,
     * otherwise returns the default `Date.getDate()` value.
     *
     * @hidden
     */
    formattedDate(value: Date): string;
    /**
     * Returns the locale representation of the year in the year view if enabled,
     * otherwise returns the default `Date.getFullYear()` value.
     *
     * @hidden
     */
    formattedYear(value: Date): string;
    /**
     * @hidden
     */
    isCurrentMonth(value: Date): boolean;
    /**
     * @hidden
     */
    isCurrentYear(value: Date): boolean;
    /**
     * @hidden
     */
    previousMonth(): void;
    /**
     * @hidden
     */
    nextMonth(): void;
    /**
     * @hidden
     */
    previousYear(): void;
    /**
     * @hidden
     */
    nextYear(): void;
    /**
     * @hidden
     */
    getFormattedDate(): {
        weekday: string;
        monthday: string;
    };
    /**
     * @hidden
     */
    childClicked(instance: ICalendarDate): void;
    animationDone(event: any, isLast: boolean): void;
    /**
     * Performs date selection through the API of the calendar component.
     * Does not trigger `onSelection` event.
     */
    selectDate(value: Date | Date[]): void;
    /**
     * @hidden
     */
    generateWeekHeader(): string[];
    /**
     * @hidden
     */
    readonly getCalendarMonth: ICalendarDate[][];
    /**
     * @hidden
     */
    changeYear(event: Date): void;
    /**
     * @hidden
     */
    changeMonth(event: Date): void;
    /**
     * @hidden
     */
    activeViewYear(): void;
    /**
     * @hidden
     */
    activeViewDecade(): void;
    /**
     * @hidden
     */
    onScroll(event: any): void;
    /**
     * @hidden
     */
    onPan(event: any): void;
    /**
     * @hidden
     */
    onKeydownPageUp(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownPageDown(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownShiftPageUp(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownShiftPageDown(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownArrowUp(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownArrowDown(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownArrowLeft(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownArrowRight(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownHome(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownEnd(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    dateTracker(index: any, item: any): string;
    /**
     * @hidden
     */
    rowTracker(index: any, item: any): string;
    /**
     * Performs a single selection.
     */
    private selectSingle(value);
    /**
     * Performs a multiple selection
     */
    private selectMultiple(value);
    private selectRange(value);
    /**
     * Helper method building and returning the context object inside
     * the calendar templates.
     */
    private generateContext(value);
    private generateDateRange(start, end);
    private generateYearRange(delta);
    private _onTouchedCallback;
    private _onChangeCallback;
}
