import { ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
export declare enum Direction {
    NONE = 0,
    NEXT = 1,
    PREV = 2,
}
/**
 * **Ignite UI for Angular Carousel** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/carousel.html)
 *
 * The Ignite UI Carousel is used to browse or navigate through a collection of slides. Slides can contain custom
 * content such as images or cards and be used for things such as on-boarding tutorials or page-based interfaces.
 * It can be used as a separate fullscreen element or inside another component.
 *
 * Example:
 * ```html
 * <igx-carousel>
 *   <igx-slide>
 *     <h3>First Slide Header</h3>
 *     <p>First slide Content</p>
 *   <igx-slide>
 *   <igx-slide>
 *     <h3>Second Slide Header</h3>
 *     <p>Second Slide Content</p>
 * </igx-carousel>
 * ```
 */
export declare class IgxCarouselComponent implements OnDestroy {
    private element;
    role: string;
    id: string;
    /**
     * Sets whether the carousel should loop back to the first slide
     * after reaching the last slide.
     *
     * Default value is true
     *
     * @memberOf IgxCarouselComponent
     */
    loop: boolean;
    /**
     * Sets whether the carousel can pause the slide transitions.
     *
     * Default value is true
     *
     * @memberOf IgxCarouselComponent
     */
    pause: boolean;
    interval: number;
    readonly tabIndex: number;
    /**
     * Controls whether the carousel should render the left/right navigation buttons.
     *
     * Default value is true
     *
     * @memberOf IgxCarouselComponent
     */
    navigation: boolean;
    /**
     * An event that is emitted after a slide transition has happened.
     * Provides a reference to the IgxCarouselComponent as an event argument.
     *
     * @memberOf IgxCarouselComponent
     */
    onSlideChanged: EventEmitter<ISlideEventArgs>;
    /**
     * An event that is emitted after a slide has been added to the carousel.
     * Provides a reference to the IgxCarousel as an event argument.
     *
     * @memberOf IgxCarouselComponent
     */
    onSlideAdded: EventEmitter<ISlideEventArgs>;
    /**
     * An event that is emitted after a slide has been removed from the carousel.
     * Provides a reference to the IgxCarouselComponent as an event argument.
     *
     * @memberOf IgxCarouselComponent
     */
    onSlideRemoved: EventEmitter<ISlideEventArgs>;
    /**
     * An event that is emitted after the carousel has been paused.
     * Provides a reference to the IgxCarousel as an event argument.
     *
     * @memberOf IgxCarouselComponent
     */
    onCarouselPaused: EventEmitter<IgxCarouselComponent>;
    /**
     * An event that is emitted after the carousel has resumed transitioning between slides.
     * Provides a reference to the IgxCarousel as an event argument.
     *
     * @memberOf IgxCarouselComponent
     */
    onCarouselPlaying: EventEmitter<IgxCarouselComponent>;
    /**
     * The collection of slides currently in the carousel
     *
     * @memberOf IgxCarouselComponent
     */
    slides: IgxSlideComponent[];
    private _interval;
    private _lastInterval;
    private _playing;
    private _currentSlide;
    private _destroyed;
    private _total;
    constructor(element: ElementRef);
    ngOnDestroy(): void;
    setAriaLabel(slide: any): string;
    /**
     * The total number of slides in the carousel.
     *
     * @readonly
     * @memberOf IgxCarouselComponent
     */
    readonly total: number;
    /**
     * The index of the slide being currently shown.
     *
     * @readonly
     * @memberOf IgxCarouselComponent
     */
    readonly current: number;
    /**
     * Returns the state of the carousel - paused or playing.
     *
     * @readonly
     * @memberOf IgxCarouselComponent
     */
    readonly isPlaying: boolean;
    /**
     * Whether the carousel is destroyed, i.e. `ngOnDestroy` has been called.
     *
     * @readonly
     * @memberOf IgxCarouselComponent
     */
    readonly isDestroyed: boolean;
    readonly nativeElement: any;
    /**
     * Returns the slide corresponding to the provided index or null.
     *
     * @param index
     * @returns
     *
     * @memberOf IgxCarouselComponent
     */
    get(index: number): IgxSlideComponent;
    /**
     * Adds a new slide to the carousel.
     *
     * @param slide
     *
     * @memberOf IgxCarouselComponent
     */
    add(slide: IgxSlideComponent): void;
    /**
     * Removes the given slide from the carousel.
     *
     * @param slide
     * @returns
     *
     * @memberOf IgxCarouselComponent
     */
    remove(slide: IgxSlideComponent): void;
    /**
     * Kicks in a transition for a given slide with a given direction.
     *
     * @param slide
     * @param [direction=Direction.NONE]
     *
     * @memberOf IgxCarouselComponent
     */
    select(slide: IgxSlideComponent, direction?: Direction): void;
    /**
     * Transitions to the next slide in the carousel.
     *
     * @returns
     *
     * @memberOf IgxCarouselComponent
     */
    next(): void;
    /**
     * Transitions to the previous slide in the carousel.
     *
     * @returns
     *
     * @memberOf IgxCarouselComponent
     */
    prev(): void;
    /**
     * Resumes playing of the carousel if in paused state.
     * No-op otherwise.
     *
     *
     * @memberOf IgxCarouselComponent
     */
    play(): void;
    /**
     * Stops slide transitions if the `pause` options is set to `true`.
     * No-op otherwise.
     *
     *
     * @memberOf IgxCarouselComponent
     */
    stop(): void;
    private _moveTo(slide, direction);
    private _resetInterval();
    private _restartInterval();
    onKeydownArrowRight(): void;
    onKeydownArrowLeft(): void;
}
/**
 * A slide component that usually holds an image and/or a caption text.
 * IgxSlideComponent is usually a child component of an IgxCarouselComponent.
 *
 * ```
 * <igx-slide [input bindings] >
 *    <ng-content></ng-content>
 * </igx-slide>
 * ```
 *
 * @export
 */
export declare class IgxSlideComponent implements OnInit, OnDestroy {
    private carousel;
    /**
     * The current index of the slide inside the carousel
     *
     * @memberOf IgxSlideComponent
     */
    index: number;
    /**
     * The target direction for the slide
     *
     * @memberOf IgxSlideComponent
     */
    direction: Direction;
    active: boolean;
    constructor(carousel: IgxCarouselComponent);
    ngOnInit(): void;
    ngOnDestroy(): void;
}
export interface ISlideEventArgs {
    carousel: IgxCarouselComponent;
    slide: IgxSlideComponent;
}
export declare class IgxCarouselModule {
}
